@@ -1267,6 +1267,30 @@ sub keybinder {
             $datacoll = 1;
         }
     }
+    elsif ($key eq "=") {
+        if (defined $matrixdata->{"recalculatetime"}) {
+            return unless &{$matrixdata->{"recalculatetime"}}($matrixwidget, $dc, $dr, $vc, $vr);
+            $datacoll = 1;
+        }
+    }
+    elsif ($key eq "~") {
+        if (defined $matrixdata->{"roundtime"}) {
+            return unless &{$matrixdata->{"roundtime"}}($matrixwidget, $dc, $dr, $vc, $vr);
+            $datacoll = 1;
+        }
+    }
+    elsif ($key eq "+") {
+        if (defined $matrixdata->{"incdatetime"}) {
+            return unless &{$matrixdata->{"incdatetime"}}($matrixwidget, $dc, $dr, $vc, $vr);
+            $datacoll = 1;
+        }
+    }
+    elsif ($key eq "-") {
+        if (defined $matrixdata->{"decdatetime"}) {
+            return unless &{$matrixdata->{"decdatetime"}}($matrixwidget, $dc, $dr, $vc, $vr);
+            $datacoll = 1;
+        }
+    }
     elsif ($key eq ":") {
         if (defined $matrixdata->{"copycellfromprevrow"}) {
             return unless &{$matrixdata->{"copycellfromprevrow"}}($matrixwidget, $dc, $dr, $vc, $vr);
